'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var constants = require('./constants.js');
var message = require('./internal/message.js');
var request = require('./internal/request.js');
var util = require('./internal/util.js');
var websocket = require('./internal/websocket.js');

class ScrapboxWebsocketHandler {
  options;
  socket = null;
  room = null;
  sid = 0;

  constructor(options) {
    this.options = options;
  }

  async commit({
    projectId,
    userId,
    pageId,
    parentId,
    changes
  }) {
    await this.join({
      projectId,
      pageId
    });
    return this.send({
      projectId,
      pageId,
      data: {
        method: 'commit',
        data: {
          kind: 'page',
          userId,
          projectId,
          pageId,
          parentId,
          changes: request.createChanges(changes, userId),
          cursor: null,
          freeze: true
        }
      }
    });
  }

  async join({
    projectId,
    pageId
  }) {
    var _this$room, _this$room2;

    // join room if needed
    if (((_this$room = this.room) === null || _this$room === void 0 ? void 0 : _this$room.projectId) === projectId && ((_this$room2 = this.room) === null || _this$room2 === void 0 ? void 0 : _this$room2.pageId) === pageId) {
      return;
    }

    await this.send({
      projectId,
      pageId,
      data: {
        method: 'room:join',
        data: {
          pageId,
          projectId,
          projectUpdatesStream: false
        }
      }
    });
    this.room = {
      projectId,
      pageId
    };
  }

  async send({
    data,
    projectId,
    pageId
  }) {
    const sid = String(this.sid++);
    this.getActiveSocket().send(message.toSocketIoMessagePayload(sid, data)).pipe(operators.first(message.isResponseOf(sid)), operators.timeout(constants.CONFIG.responseTimeout));
  }

  getActiveSocket() {
    var _this$socket;

    return !((_this$socket = this.socket) !== null && _this$socket !== void 0 && _this$socket.active) ? this.socket = this.openNewSocket() : this.socket;
  }

  openNewSocket() {
    const socket = new websocket.RxWebSocket({
      url: constants.CONFIG.endpoint,
      options: {
        headers: {
          Origin: constants.CONFIG.origin,
          Cookie: util.getAuthCookieValue(this.options.token ?? '')
        }
      },
      serializer: message.scrapboxSerializer,
      deserializer: message.scrapboxDeserializer
    });
    socket.message.pipe(operators.first(message.isConnectionMessage)).subscribe(([, data]) => {
      socket.send(constants.packetTypes.connected);
      rxjs.interval(data.pingInterval).pipe(operators.takeUntil(socket.message)).subscribe(() => socket.send(constants.packetTypes.ping));
    });
    return socket;
  }

}

exports.ScrapboxWebsocketHandler = ScrapboxWebsocketHandler;
//# sourceMappingURL=websocket-handler.js.map
