import { Observable } from 'rxjs';

const getHistoryEventObservable = (w = window) => {
    return new Observable((subscriber) => {
        const originPushState = w.history.pushState;
        const originReplaceState = w.history.replaceState;
        const patchedPushState = (state, title, url) => {
            // NOTE: to avoid `TypeError: Illegal invocation`
            originPushState.call(w.history, state, title, url);
            subscriber.next(w.location.href);
        };
        const patchedReplaceState = (state, title, url) => {
            // NOTE: to avoid `TypeError: Illegal invocation`
            originReplaceState.call(w.history, state, title, url);
            subscriber.next(w.location.href);
        };
        const onPopstate = () => subscriber.next(w.location.href);
        w.history.pushState = patchedPushState.bind(w.history);
        w.history.replaceState = patchedReplaceState.bind(w.history);
        w.addEventListener('popstate', onPopstate);
        return () => {
            w.history.pushState = originPushState;
            w.history.replaceState = originReplaceState;
            w.removeEventListener('popstate', onPopstate);
        };
    });
};

export { getHistoryEventObservable };
//# sourceMappingURL=observable.js.map
