import { Observable, timer } from 'rxjs';
import { share } from 'rxjs/operators';

const findElementOrFail = (selector, parent = document) => {
    const elem = parent.querySelector(selector);
    if (!elem) {
        throw new Error('Element not found');
    }
    return elem;
};
const nodeChange = (node, options) => {
    return new Observable((subscriber) => {
        const mo = new MutationObserver(() => subscriber.next());
        mo.observe(node, options);
        return () => mo.disconnect();
    }).pipe(share());
};
// NOTE: scrapbox.Project.name is set after react bootstrapped
const isScrapboxReady = () => Boolean(window.scrapbox.Project && window.scrapbox.Project.name);
const scrapboxReady = () => {
    return new Observable((subscriber) => {
        const subscription = timer(0, 30).subscribe(() => {
            if (isScrapboxReady()) {
                subscriber.next(window.scrapbox);
                subscriber.complete();
                subscription.unsubscribe();
            }
        });
        return subscription;
    });
};

export { findElementOrFail, isScrapboxReady, nodeChange, scrapboxReady };
//# sourceMappingURL=util.js.map
